@@ -1,17 +1,9 @@
-from warnings import warn
-from django.conf import settings
+from serrano.conf import settings
 
 
 def patch_response(request, response, methods):
-    if getattr(settings, 'SERRANO_CORS_ENABLED', False):
-        if hasattr(settings, 'SERRANO_CORS_ORIGIN'):
-            warn('SERRANO_CORS_ORIGIN has been deprecated in favor '
-                 'of SERRANO_CORS_ORIGINS', DeprecationWarning)
-            allowed_origins = [s.strip() for s in
-                               settings.SERRANO_CORS_ORIGIN.split(',')]
-        else:
-            allowed_origins = getattr(settings, 'SERRANO_CORS_ORIGINS', ())
-
+    if settings.CORS_ENABLED:
+        allowed_origins = settings.CORS_ORIGINS
         origin = request.META.get('HTTP_ORIGIN')
 
         if not allowed_origins or origin in allowed_origins:
